@@ -3,6 +3,6 @@ var threeOBJ = require("../index")(),
 
 //threeOBJ.set({ align: "bottom" });
 
-threeOBJ.minify("./obj/palm.obj", "./binary/palm.js", function( response ){
+threeOBJ.minify("./import/mesh.obj", "./export/mesh.js", function( response ){
 	console.log( "File saved at: binary/palm.js"  );
 });
