@@ -5,6 +5,7 @@ var fs = require("fs"),
 var keyMap = {
 	kd : "colorDiffuse", // Diffuse color: Kd 1.000 1.000 1.000
 	ka : "colorAmbient", // Ambient color: Ka 1.000 1.000 1.000
+	ke : "colorEmissive", // Emissive color: Ke 0.000 0.000 0.000
 	ks : "colorSpecular", // Specular color: Ks 1.000 1.000 1.000
 	ns : "specularCoef", // Specular coefficient: Ns 154.000
 	tr : "opacity", // Transparency: Tr 0.9 or d 0.9
@@ -12,6 +13,7 @@ var keyMap = {
 	ni : "opticalDensity", // Optical density: Ni 1.0
 	map_kd : "mapDiffuse", // Diffuse texture: map_Kd texture_diffuse.jpg
 	map_ka : "mapAmbient", // Ambient texture: map_Ka texture_ambient.jpg
+	map_ke : "mapEmissive", // Emissive texture: map_Ka texture_ambient.jpg
 	map_ks : "mapSpecular", // Specular texture: map_Ks texture_specular.jpg
 	map_ns : "mapSpecular", // Specular texture: map_Ns texture_specular.jpg
 	map_d : "mapAlpha", // Alpha texture: map_d texture_alpha.png
@@ -88,8 +90,10 @@ function parser( mtl, options ){
 			materials.push(material);
 
 		} else if ( materials.length > 0 ) {
-			// colorAmbient disabled for THREE.js > r80
-			if ( key === "ka" ) continue;
+			// skip under certain conditions
+			// - colorAmbient disabled for THREE.js > r80
+			// - colorEmissive not supported
+			if ( key === "ka" || key === "ke" || key === "map_ke" ) continue;
 
 			if ( key === "kd" || key === "ks" ) {
 
